@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: andrius $
-#$Date: 2020-02-18 02:10:02 -0500 (Tue, 18 Feb 2020) $ 
-#$Revision: 6072 $
-#$URL: svn://saulius-grazulis.lt/restful/tags/v0.15.0/lib/Database/View.pm $
+#$Date: 2020-12-09 10:07:18 -0500 (Wed, 09 Dec 2020) $ 
+#$Revision: 7130 $
+#$URL: svn://saulius-grazulis.lt/restful/tags/v0.15.2/lib/Database/View.pm $
 #------------------------------------------------------------------------------
 #*
 #  An object to encapsulate a view in a database.
@@ -36,7 +36,9 @@ sub new
         $sql =~ s/'/`/g;
 
     } else {
-        my $sth = $db->{db}{content}{dbh}->prepare( "show create view `$table`" );
+        my $delim = $db->{db}{content}{delim};
+        my $sth = $db->{db}{content}{dbh}->prepare( 'show create view ' .
+                                                    $delim . $table . $delim );
         $sth->execute;
         $sql = $sth->fetchrow_hashref->{'Create View'};
     }
