@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: alex $
-#$Date: 2020-08-03 01:02:39 -0400 (Mon, 03 Aug 2020) $ 
-#$Revision: 7094 $
-#$URL: svn://saulius-grazulis.lt/restful/tags/v0.15.0/lib/RestfulDB/Schema/DBI.pm $
+#$Author: andrius $
+#$Date: 2020-12-22 04:44:09 -0500 (Tue, 22 Dec 2020) $ 
+#$Revision: 7142 $
+#$URL: svn://saulius-grazulis.lt/restful/tags/v0.15.2/lib/RestfulDB/Schema/DBI.pm $
 #------------------------------------------------------------------------------
 #*
 #  An object to metadata queries for the RestfulDB interface when the
@@ -18,7 +18,6 @@ use parent 'RestfulDB::Schema';
 
 use DBI;
 use File::Basename qw(basename);
-use File::MimeInfo::Magic;
 use List::MoreUtils qw(uniq);
 use List::Util qw(any);
 use POSIX qw(strftime);
@@ -779,6 +778,54 @@ sub get_fk_format
     return $db->{fk_formats}{$table};
 }
 
+sub get_table_properties
+{
+    my( $db, $table ) = @_;
+
+    if( exists $db->{table_properties}{$table} ) {
+        return wantarray ?
+            %{$db->{table_properties}{$table}} :
+              $db->{table_properties}{$table};
+    }
+
+    for ($db->get_table_list) {
+        # By default views are read-only
+        $db->{table_properties}{$_}{is_read_only} =
+            $db->is_view( $_ );
+    }
+
+    if( $db->{db}{meta} && $db->{db}{meta}{dbh} &&
+        any { $_ eq 'table_description' }
+            Database::_get_table_list( $db->{db}{meta}{dbh} ) ) {
+        my $delim = $db->{db}{meta}{delim};
+        my $sql_statement = "SELECT * FROM ${delim}table_description${delim} " .
+                            'WHERE dbname = ?';
+        my @dbnames = ( $db->{db}{content}{DB} );
+        if( $db->{db}{content}{engine} ne 'mysql' ) {
+            $sql_statement .= ' OR dbname = ?';
+            push @dbnames, basename $db->{db}{content}{DB};
+        }
+        print STDERR "$sql_statement\n" if $debug_sql;
+        my $dbh = $db->{db}{meta}{dbh};
+        my $sth = $dbh->prepare( $sql_statement ) or
+            $db->error( "could not prepare SELECT statement: $DBI::errstr" );
+        $sth->execute( @dbnames ) or
+            $db->error( "Execution of $sql_statement failed: $DBI::errstr" );
+
+        while( my $row = $sth->fetchrow_hashref ) {
+            my( $dbtable, $is_read_only ) =
+                ( $row->{dbtable}, $row->{is_read_only} );
+
+            next unless defined $is_read_only;
+            $db->{table_properties}{$dbtable}{is_read_only} = $is_read_only;
+        }
+    }
+
+    return wantarray ?
+        %{$db->{table_properties}{$table}} :
+          $db->{table_properties}{$table};
+}
+
 sub get_grants
 {
     my( $db ) = @_;
