@@ -1097,43 +1097,43 @@ eval {
 
             my $filter_qs = $filter->query_string_uri if $filter;
 
+            # Spreadsheet download form.
+            my $template_form_uri =
+                transfer_query_string(
+                    $base_uri,
+                    $ENV{REQUEST_URI},
+                    { exclude_re => 'select_.*|search_value|.cgifields|rows|offset',
+                      append => $filter_qs },
+                );
+
+            $html .= start_div( { -class => 'related expandable row',
+                                  -for => "spreadsheet-panels",
+                                  -id => 'spreadsheet-panels' } ) .
+                     start_div( { -class => 'col-sm-12 col-md-12 col-lg-12' } );
+            $html .= start_form_QS( -action => $template_form_uri,
+                                    -method => 'get',
+                                    -class => 'form_init' ) .
+                     popup_menu( -name => 'format',
+                                 -values => [ 'csv', 'csv zip', 'ods', 'xls', 'xlsx' ],
+                                 -default => 'csv',
+                                 -labels => { 'csv' => 'CSV',
+                                              'csv zip' => 'CSV+ZIP',
+                                              'ods' => 'ODS',
+                                              'xls' => 'XLS',
+                                              'xlsx' => 'XLSX' } ) .
+                     nameless_submit( 'Download data' ) .
+                     hidden( { -name => 'depth', -value => 'auto' } ) .
+                     'Rows in data file:' .
+                     textfield( -name => 'rows', -default => $params{rows}, -size => 5 ) .
+                     '<button name="action" class="' . button_classes_string() .
+                     '" type="submit" value="template">Download template' .
+                     '</button>' .
+                     'Rows in template file:' .
+                     textfield( -name => 'rows_template', -default => 0, -size => 5 ) .
+                     end_form;
+
+            # Spreadsheet upload form.
             if( !$db->is_view( $db_table ) ) {
-                # Spreadsheet download form.
-                my $template_form_uri =
-                    transfer_query_string(
-                        $base_uri,
-                        $ENV{REQUEST_URI},
-                        { exclude_re => 'select_.*|search_value|.cgifields|rows|offset',
-                          append => $filter_qs },
-                    );
-
-                $html .= start_div( { -class => 'related expandable row',
-                                      -for => "spreadsheet-panels",
-                                      -id => 'spreadsheet-panels' } ) .
-                         start_div( { -class => 'col-sm-12 col-md-12 col-lg-12' } );
-                $html .= start_form_QS( -action => $template_form_uri,
-                                        -method => 'get',
-                                        -class => 'form_init' ) .
-                         popup_menu( -name => 'format',
-                                     -values => [ 'csv', 'csv zip', 'ods', 'xls', 'xlsx' ],
-                                     -default => 'csv',
-                                     -labels => { 'csv' => 'CSV',
-                                                  'csv zip' => 'CSV+ZIP',
-                                                  'ods' => 'ODS',
-                                                  'xls' => 'XLS',
-                                                  'xlsx' => 'XLSX' } ) .
-                         nameless_submit( 'Download data' ) .
-                         hidden( { -name => 'depth', -value => 'auto' } ) .
-                         'Rows in data file:' .
-                         textfield( -name => 'rows', -default => $params{rows}, -size => 5 ) .
-                         '<button name="action" class="' . button_classes_string() .
-                         '" type="submit" value="template">Download template' .
-                         '</button>' .
-                         'Rows in template file:' .
-                         textfield( -name => 'rows_template', -default => 0, -size => 5 ) .
-                         end_form;
-
-                # Spreadsheet upload form.
                 $html .= start_form( -method => 'post',
                                      -class => 'form_init' ) .
                          popup_menu( -name => 'upload_format',
@@ -1151,11 +1151,10 @@ eval {
                          '</button>' .
                          filefield( -name => 'spreadsheet' ) .
                          end_form;
-
-                $html .= end_div() . end_div(); # Close row and column containers.
             }
 
-            $html .= end_div() . "\n"; # Close the first section.
+            # Close row and column containers and then the first section.
+            $html .= end_div() . end_div() . end_div() . "\n";
 
             # Start another section.
             $html .= start_div( {-class => "section",
